pub fn azure_chatbot_configuration(
app_config: &ApplicationConfiguration,
) -> ChatbotResult<&AzureChatbotConfiguration>Expand description
The Azure chatbot (Foundry) section of the application configuration, or an error naming what’s missing.
pub fn azure_chatbot_configuration(
app_config: &ApplicationConfiguration,
) -> ChatbotResult<&AzureChatbotConfiguration>The Azure chatbot (Foundry) section of the application configuration, or an error naming what’s missing.