pub fn azure_configuration(
app_config: &ApplicationConfiguration,
) -> ChatbotResult<&AzureConfiguration>Expand description
The Azure section of the application configuration, or an error naming what’s missing.
pub fn azure_configuration(
app_config: &ApplicationConfiguration,
) -> ChatbotResult<&AzureConfiguration>The Azure section of the application configuration, or an error naming what’s missing.