pub fn parse_text_completion(completion: LLMResponse) -> ChatbotResult<String>Expand description
Collects all the completion choices to a string. Assumes the completion has only text message content, no tool calls or tool output.
pub fn parse_text_completion(completion: LLMResponse) -> ChatbotResult<String>Collects all the completion choices to a string. Assumes the completion has only text message content, no tool calls or tool output.