fn stored_summary(text: Option<String>) -> Vec<ReasoningOutput>Expand description
A stored summary text as the summary parts that go back to Azure.
fn stored_summary(text: Option<String>) -> Vec<ReasoningOutput>A stored summary text as the summary parts that go back to Azure.